@@ -15,16 +15,20 @@ sub start {
     my %args  = @_;
 
     # check if we have redis-server
-    return unless grep { -x } map { File::Spec->catfile( $_, $REDIS_SERVER ) } File::Spec->path;
+    return unless grep { -x } map { File::Spec->catfile($_, $REDIS_SERVER) } File::Spec->path;
 
     my $requirepass = $args{password} ? "requirepass $args{password}" : "";
-    $args{dir} = File::Temp::tempdir( 'test_redisXXXXXX', TMPDIR => 1, CLEANUP => 0 );
+    $args{dir} = File::Temp::tempdir(
+        'test_redisXXXXXX',
+        TMPDIR  => 1,
+        CLEANUP => 0
+    );
 
     my $self = bless \%args, $class;
     $self->{_t_tcp} = Test::TCP->new(
         code => sub {
             my $port    = shift;
-            my $logfile = File::Spec->catfile( $args{dir}, "redis_test.log" );
+            my $logfile = File::Spec->catfile($args{dir}, "redis_test.log");
             my $cfg     = <<EOC;
 daemonize no
 port $port
@@ -36,10 +40,10 @@ dbfilename dump_test.rdb
 dir $args{dir}
 $requirepass
 EOC
-            open my $cfg_fd, ">", File::Spec->catfile( $args{dir}, "redis.cfg" ) or die $!;
+            open my $cfg_fd, ">", File::Spec->catfile($args{dir}, "redis.cfg") or die $!;
             print $cfg_fd $cfg;
             close $cfg_fd;
-            exec $REDIS_SERVER, File::Spec->catfile( $self->{dir}, "redis.cfg" );
+            exec $REDIS_SERVER, File::Spec->catfile($self->{dir}, "redis.cfg");
         },
     );
     $self->{port} = $self->{_t_tcp}->port;
